@@ -9,11 +9,13 @@ use Exporter qw{ import };
 use HTTP::Date;
 use Test::More 0.96;	# For subtest
 
-our $VERSION = '0.085_01';
+our $VERSION = '0.086_02';
 
 # Set the following to zero if Space Track (or any other SSL host)
 # starts using a certificate that can not be verified.
-use constant VERIFY_HOSTNAME => 1;
+use constant VERIFY_HOSTNAME => defined $ENV{SPACETRACK_VERIFY_HOSTNAME}
+    ? $ENV{SPACETRACK_VERIFY_HOSTNAME}
+    : 0;
 
 our @EXPORT = qw{
     is_error
